@@ -3,33 +3,42 @@ use strict;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '2.055';
+$VERSION = '2.065';
 
-use Mail::Message::Head::Complete;
-use Mail::Message::Body::Lines;
-use Mail::Message::Body::Multipart;
-use Mail::Message::Field;
+use Mail::Message::Head::Complete  ();
+use Mail::Message::Body::Lines     ();
+use Mail::Message::Body::Multipart ();
+use Mail::Message::Body::Nested    ();
+use Mail::Message::Field           ();
 
-use Mail::Address;
-use Carp;
-use Scalar::Util 'blessed';
-use IO::Lines;
+use Mail::Address  ();
 
 
 sub build(@)
 {   my $class = shift;
 
+    if($class->isa('Mail::Box::Message'))
+    {   $class->log(ERROR
+           => "Only build() Mail::Message's; they are not in a folder yet"); 
+         return undef;
+    }
+
     my @parts
       = ! ref $_[0] ? ()
       : $_[0]->isa('Mail::Message')       ? shift
       : $_[0]->isa('Mail::Message::Body') ? shift
       :               ();
 
-    my ($head, $type, @headerlines);
+    my ($head, @headerlines);
+    my ($type, $transfenc, $dispose, $descr);
     while(@_)
     {   my $key = shift;
         if(ref $key && $key->isa('Mail::Message::Field'))
-        {   if($key->name eq 'content-type') { $type = $key }
+        {   my $name = $key->name;
+               if($name eq 'content-type')              { $type      = $key }
+            elsif($name eq 'content-transfer-encoding') { $transfenc = $key }
+            elsif($name eq 'content-disposition')       { $dispose   = $key }
+            elsif($name eq 'content-description')       { $descr     = $key }
             else { push @headerlines, $key }
             next;
         }
@@ -48,13 +57,26 @@ sub build(@)
         elsif($key eq 'files')
         {   @data = map {Mail::Message::Body->new(file => $_) } @$value }
         elsif($key eq 'attach')
-        {   @data = ref $value eq 'ARRAY' ? @$value : $value }
-        elsif(lc $key eq 'content-type')
-        {   $type = Mail::Message::Field->new($key, $value) }
+        {   foreach my $c (ref $value eq 'ARRAY' ? @$value : $value)
+	    {   push @data, $c->isa('Mail::Message')
+		          ? Mail::Message::Body::Nested->new(nested => $c)
+			  : $c;
+            }
+	}
+        elsif($key =~
+           m/^content\-(type|transfer\-encoding|disposition|description)$/i )
+        {   my $k     = lc $1;
+            my $field = Mail::Message::Field->new($key, $value);
+               if($k eq 'type')         { $type = $field }
+            elsif($k eq 'disposition' ) { $dispose = $field }
+            elsif($k eq 'description' ) { $descr    = $field }
+            else { $transfenc = $field }
+        }
         elsif($key =~ m/^[A-Z]/)
         {   push @headerlines, $key, $value }
         else
-        {   croak "Skipped unknown key $key in build." } 
+        {   $class->log(WARNING => "Skipped unknown key $key in build");
+        }
 
         push @parts, grep {defined $_} @data if @data;
     }
@@ -66,6 +88,9 @@ sub build(@)
 
     # Setting the type explicitly, only after the body object is finalized
     $body->type($type) if defined $type;
+    $body->disposition($dispose) if defined $dispose;
+    $body->description($descr) if defined $descr;
+    $body->transferEncoding($transfenc) if defined $transfenc;
 
     $class->buildFromBody($body, $head, @headerlines);
 }
@@ -109,4 +134,7 @@ sub buildFromBody(@)
     $message;
 }
 
+#------------------------------------------
+
+
 1;
