@@ -3,7 +3,7 @@ use warnings;
 
 package Mail::Message::Field;
 use vars '$VERSION';
-$VERSION = '2.055';
+$VERSION = '2.065';
 use base 'Mail::Reporter';
 
 use Carp;
@@ -40,6 +40,8 @@ sub new(@)
 #------------------------------------------
 
 
+sub length { length shift->folded }
+
 #------------------------------------------
 
 
@@ -49,9 +51,8 @@ BEGIN {
      Resent-Date Resent-From Resent-Sender Resent-To Return-Path
      List-Help List-Post List-Unsubscribe Mailing-List
      Received References Message-ID In-Reply-To
-     Content-Length Content-Type
+     Content-Type Content-Disposition
      Delivered-To
-     Lines
      MIME-Version
      Precedence
      Status/;
@@ -74,7 +75,7 @@ sub print(;$)
 #------------------------------------------
 
 
-sub toString(;$) {my $self = shift;$self->string(@_)}
+sub toString(;$) {shift->string(@_)}
 sub string(;$)
 {   my $self  = shift;
     return $self->folded unless @_;
@@ -105,7 +106,7 @@ sub nrLines() { my @l = shift->foldedBody; scalar @l }
 #------------------------------------------
 
 
-sub size() {length shift->toString}
+*size = \&length;
 
 #------------------------------------------
 
@@ -119,7 +120,7 @@ sub size() {length shift->toString}
 
 my %wf_lookup
   = qw/mime MIME  ldap LDAP  soap SOAP  swe SWE
-       bcc Bcc  cc Cc/;
+       bcc Bcc  cc Cc  id ID/;
 
 sub wellformedName(;$)
 {   my $thing = shift;
@@ -127,12 +128,14 @@ sub wellformedName(;$)
 
     join '-',
        map { $wf_lookup{lc $_} || ( /[aeiouyAEIOUY]/ ? ucfirst lc : uc ) }
-          split /\-/, $name;
+          split /\-/, $name, -1;
 }
 
 #------------------------------------------
 
 
+sub folded { shift->notImplemented }
+
 #------------------------------------------
 
 
@@ -148,6 +151,8 @@ sub body()
 #------------------------------------------
 
 
+sub foldedBody { shift->notImplemented }
+
 #------------------------------------------
 
 
@@ -171,7 +176,7 @@ sub stripCFWS($)
     while(@s)
     {   my $s = shift @s;
 
-           if(length $r && substr($r, -1) eq "\\") { $r .= $s } # esc'd special
+           if(CORE::length($r)&& substr($r, -1) eq "\\")  { $r .= $s }
         elsif($s eq '"')   { $in_dquotes = not $in_dquotes; $r .= $s }
         elsif($s eq '(' && !$in_dquotes) { $open_paren++ }
         elsif($s eq ')' && !$in_dquotes) { $open_paren-- }
@@ -201,7 +206,7 @@ sub comment(;$)
     if(@_)
     {   my $comment = shift;
         $body    =~ s/\s*\;.*//;
-        $body   .= "; $comment" if defined $comment && length $comment;
+        $body   .= "; $comment" if defined $comment && CORE::length($comment);
         $self->unfoldedBody($body);
         return $comment;
     }
@@ -225,7 +230,7 @@ sub attribute($;$)
            $body =~ m/\b$attr\s*\=\s*
                        ( "( (?: [^"]|\\" )* )"
                        | '( (?: [^']|\\' )* )'
-                       | (\S*)
+                       | ([^;\s]*)
                        )
                   /xi ? $+ : undef;
     }
@@ -235,7 +240,7 @@ sub attribute($;$)
     {   for($body)
         {      s/\b$attr\s*=\s*'([^']|\\')*'//i
             or s/\b$attr\s*=\s*"([^"]|\\")*"//i
-            or s/\b$attr\s*=\s*\S*//i;
+            or s/\b$attr\s*=\s*[;\s]*//i;
         }
         $self->unfoldedBody($body);
         return undef;
@@ -245,7 +250,7 @@ sub attribute($;$)
     for($body)
     {       s/\b$attr\s*=\s*'([^']|\\')*'/$attr="$quoted"/i
          or s/\b$attr\s*=\s*"([^"]|\\")*"/$attr="$quoted"/i
-         or s/\b$attr\s*=\s*\S+/$attr="$quoted"/i
+         or s/\b$attr\s*=\s*[^;\s]+/$attr="$quoted"/i
          or do { $_ .= qq(; $attr="$quoted") }
     }
 
@@ -256,6 +261,26 @@ sub attribute($;$)
 #------------------------------------------
 
 
+sub attributes()
+{   my $self  = shift;
+    my $body  = $self->unfoldedBody;
+
+    my @attrs;
+    while($body =~ m/\b(\w+)\s*\=\s*
+                       ( "( (?: [^"]|\\" )* )"
+                       | '( (?: [^']|\\' )* )'
+                       | ([^;\s]*)
+                       )
+                    /xig)
+    {   push @attrs, $1 => $+;
+    }
+
+    @attrs;
+}
+
+#------------------------------------------
+
+
 sub toInt()
 {   my $self = shift;
     return $1 if $self->body =~ m/^\s*(\d+)\s*$/;
@@ -278,7 +303,7 @@ sub toDate(@)
     my $time   = strftime($format, @time);
 
     # for C libs which do not (GNU compliantly) support %z
-    $time =~ s/ (\%z|[A-Z]+)$/_tz_offset($1)/e;
+    $time =~ s/ (\%z|[A-Z ]+)$/_tz_offset($1)/e;
 
     $time; 
 }
@@ -289,7 +314,7 @@ sub _tz_offset($)
 
    my $diff = $zone eq '%z' ? Time::Zone::tz_local_offset()
            :                  Time::Zone::tz_offset($zone);
-   my $minutes = int((abs($diff)+0.01) / 60);     # float rounding errors :(
+   my $minutes = int((abs($diff)+0.01) / 60);     # float rounding errors
    my $hours   = int(($minutes+0.01) / 60);
    $minutes   -= $hours * 60;
    sprintf( ($diff < 0 ? " -%02d%02d" : " +%02d%02d"), $hours, $minutes);
@@ -354,7 +379,7 @@ sub consume($;$)
         $body =~ s/[\012\015]+/\n/g;
         $body =~ s/^[ \t]*/ /;  # start with one blank, folding kept unchanged
 
-        $self->log(NOTICE => "Empty field: $name\n")
+        $self->log(NOTICE => "Empty field: $name")
            if $body eq " \n";
     }
 
@@ -398,8 +423,8 @@ sub stringifyData($)
 sub setWrapLength(;$)
 {   my $self = shift;
 
-    $self->[1] = $self->fold($self->[0],$self->unfoldedBody, @_)
-        if @_ || $self->[1] !~ m/\n$/;
+    $self->foldedBody(scalar $self->fold($self->Name, $self->unfoldedBody, @_))
+        if @_;
 
     $self;
 }
@@ -422,13 +447,13 @@ sub fold($$;$)
     my $wrap  = shift || $default_wrap_length;
 
     $line    =~ s/\n\s/ /gms;            # Remove accidental folding
-    return " \n" unless length $line;    # empty field
+    return " \n" unless CORE::length($line);  # empty field
 
     my @folded;
     while(1)
-    {  my $max = $wrap - (@folded ? 1 : length($name) + 2);
+    {  my $max = $wrap - (@folded ? 1 : CORE::length($name) + 2);
        my $min = $max >> 2;
-       last if length $line < $max;
+       last if CORE::length($line) < $max;
 
           $line =~ s/^ ( .{$min,$max}   # $max to 30 chars
                         [;,]            # followed at a ; or ,
@@ -445,7 +470,7 @@ sub fold($$;$)
        push @folded, " $1\n";
     }
 
-    push @folded, " $line\n" if length $line;
+    push @folded, " $line\n" if CORE::length($line);
     wantarray ? @folded : join('', @folded);
 }
 
@@ -455,7 +480,7 @@ sub fold($$;$)
 sub unfold($)
 {   my $string = $_[1];
     for($string)
-    {   s/\n//g;
+    {   s/\r?\n//gm;
         s/^ +//;
     }
     $string;
