@@ -3,17 +3,19 @@ use warnings;
 
 package Mail::Message::Field::Full;
 use vars '$VERSION';
-$VERSION = '2.055';
+$VERSION = '2.065';
 use base 'Mail::Message::Field';
 
-use Mail::Message::Field::Attribute;
-
 use utf8;
 use Encode ();
 use MIME::QuotedPrint ();
 use Storable 'dclone';
 
-use Carp;
+use Mail::Message::Field::Structured;
+use Mail::Message::Field::Unstructured;
+use Mail::Message::Field::Addresses;
+use Mail::Message::Field::URIs;
+
 my $atext = q[a-zA-Z0-9!#\$%&'*+\-\/=?^_`{|}~];  # from RFC
 
 
@@ -34,6 +36,8 @@ BEGIN {
    $implementation{$_} = 'URIs' foreach
       qw/list-help list-post list-subscribe list-unsubscribe list-archive
          list-owner/;
+   $implementation{$_} = 'Structured' foreach
+      qw/content-disposition content-type/;
 #  $implementation{$_} = 'Date' foreach
 #     qw/date resent-date/;
 }
@@ -44,7 +48,7 @@ sub new($;$$@)
     my $body   = @_ % 2 ? shift : undef;
     my %args   = @_;
 
-    $body    ||= delete $args{body};
+    $body      = delete $args{body} if defined $args{body};
     unless(defined $body)
     {   (my $n, $body) = split /\s*\:\s*/s, $name, 2;
         $name = $n if defined $body;
@@ -57,9 +61,6 @@ sub new($;$$@)
     my $myclass = 'Mail::Message::Field::'
                 . ($implementation{lc $name} || 'Unstructured');
 
-    eval "require $myclass";
-    return if $@;
-
     $myclass->SUPER::new(%args, name => $name, body => $body);
 }
 
@@ -85,13 +86,6 @@ sub clone() { dclone(shift) }
 
 #------------------------------------------
 
-sub length()
-{   my $self = shift;
-    croak;
-}
-
-#------------------------------------------
-
 sub name() { lc shift->{MMFF_name}}
 
 #------------------------------------------
@@ -116,7 +110,7 @@ sub unfoldedBody($;$)
 {   my ($self, $body) = (shift, shift);
 
     if(defined $body)
-    {    $self->foldedBody($self->fold($self->{MMFF_name}, $body));
+    {    $self->foldedBody(scalar $self->fold($self->{MMFF_name}, $body));
          return $body;
     }
 
@@ -252,12 +246,12 @@ sub encode($@)
         $qp      =~ s#([_\?])#sprintf "=%02X", ord $1#ge;
         $qp      =~ s/ /_/g;
 
-        my $take = 72 - CORE::length($pre);
-        while(CORE::length($qp) > $take)
+        my $take = 70 - CORE::length($pre);
+        while(CORE::length($qp) > $take+1)
         {   $qp =~ s#^(.{$take}.?.?[^=][^=])## or warn $qp;
             $ready .= "$pre$1?= ";
         }
-        $ready .= "$pre$qp?=" if CORE::length $qp;
+        $ready .= "$pre$qp?=" if CORE::length($qp);
     }
 
     else
@@ -384,6 +378,11 @@ sub consumeDotAtom($)
 
 #------------------------------------------
 
+                                                                                
+sub produceBody() { die }
+
+#------------------------------------------
+
 
 
 1;
